================
About tl.eggdeps
================

:Author:
    `Thomas Lotze <http://thomas-lotze.de/>`_ <thomas@thomas-lotze.de>

:Web home:
    http://thomas-lotze.de/en/software/eggdeps/

:Online documentation:
    http://packages.python.org/tl.eggdeps/

:PyPI page:
    http://pypi.python.org/pypi/tl.eggdeps/

:GitHub:
    https://github.com/tlotze/tl.eggdeps

:Current change log:
    https://github.com/tlotze/tl.eggdeps/blob/master/CHANGES.txt


.. Local Variables:
.. mode: rst
.. End:
